Data directory
==============

The data used in this package come from the following sources.

* Tables of X-Ray Mass Attenuation Coefficients and Mass Energy-Absorption Coefficients from 1 keV to 20 MeV for Elements Z = 1 to 92 and 48 Additional Substances of Dosimetric Interest](http://www.nist.gov/pml/data/xraycoef/index.cfm) | J. H. Hubbell, S. M. Seltzer | NIST |


elements.csv
------------
density is in units of g/cm^3

compounds_mixtures.csv
----------------------
density is in units of g/cm^3

emission_energies.csv
---------------------
energies are in eV
